@@ -8,4 +8,5 @@ def gen_password(password_len, password_count):
             for x in range(0,password_len):
                 password_char = random.choice(chars)
                 password+=password_char
-        return password+"\n\n"
+            password = password+"\n\n"
+        return password
